@@ -10,7 +10,6 @@ def casing():
     import math
    # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
     from RocketCasing import materials
-   # import materials
     from datetime import datetime
 
 #Abertura do programa
@@ -131,6 +130,3 @@ def casing():
     arquivo.write('\n')
     arquivo.write(' ')
     arquivo.close()
-
-#Chamando a definição que o código foi colocado    
-casing()
\ No newline at end of file
